package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallGoodsSpec;

/**
 * 商品规格名Mapper接口
 *
 * @author chang
 * @date 2021-11-25
 */
public interface MallGoodsSpecMapper
{
    /**
     * 查询商品规格名
     *
     * @param id 商品规格名主键
     * @return 商品规格名
     */
    public MallGoodsSpec selectMallGoodsSpecById(Long id);

    /**
     * 查询商品规格名列表
     *
     * @param mallGoodsSpec 商品规格名
     * @return 商品规格名集合
     */
    public List<MallGoodsSpec> selectMallGoodsSpecList(MallGoodsSpec mallGoodsSpec);

    /**
     * 查询商品规格名列表
     *
     * @param mallGoodsSpec 商品规格名
     * @return 商品规格名集合
     */
    public List<MallGoodsSpec> selectMallGoodsSpecSelectList(MallGoodsSpec mallGoodsSpec);

    /**
     * 新增商品规格名
     *
     * @param mallGoodsSpec 商品规格名
     * @return 结果
     */
    public int insertMallGoodsSpec(MallGoodsSpec mallGoodsSpec);

    /**
     * 修改商品规格名
     *
     * @param mallGoodsSpec 商品规格名
     * @return 结果
     */
    public int updateMallGoodsSpec(MallGoodsSpec mallGoodsSpec);

    /**
     * 删除商品规格名
     *
     * @param id 商品规格名主键
     * @return 结果
     */
    public int deleteMallGoodsSpecById(Long id);

    /**
     * 批量删除商品规格名
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallGoodsSpecByIds(Long[] ids);
}
