package com.ruoyi.mall.controller;

import java.util.List;

import com.ruoyi.mall.domain.MallGoodsSpecValue;
import com.ruoyi.mall.service.IMallGoodsSpecValueService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallGoodsSpec;
import com.ruoyi.mall.service.IMallGoodsSpecService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商品规格名Controller
 *
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallGoodsSpec")
public class MallGoodsSpecController extends BaseController
{
    @Autowired
    private IMallGoodsSpecService mallGoodsSpecService;
    @Autowired
    private IMallGoodsSpecValueService mallGoodsSpecValueService;

    /**
     * 查询商品规格名列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpec:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallGoodsSpec mallGoodsSpec)
    {
        startPage();
        List<MallGoodsSpec> list = mallGoodsSpecService.selectMallGoodsSpecList(mallGoodsSpec);
        return getDataTable(list);
    }

    /**
     * 导出商品规格名列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpec:export')")
    @Log(title = "商品规格名", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallGoodsSpec mallGoodsSpec)
    {
        List<MallGoodsSpec> list = mallGoodsSpecService.selectMallGoodsSpecList(mallGoodsSpec);
        ExcelUtil<MallGoodsSpec> util = new ExcelUtil<MallGoodsSpec>(MallGoodsSpec.class);
        return util.exportExcel(list, "商品规格名数据");
    }

    /**
     * 获取商品规格名详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpec:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallGoodsSpecService.selectMallGoodsSpecById(id));
    }

    /**
     * 新增商品规格名
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpec:add')")
    @Log(title = "商品规格名", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallGoodsSpec mallGoodsSpec)
    {
        if (mallGoodsSpec.getSpec().size()<1){
            return AjaxResult.error("至少有一个规格");
        }
        return AjaxResult.success(mallGoodsSpecService.insertMallGoodsSpec(mallGoodsSpec));
    }

    /**
     * 修改商品规格名
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpec:edit')")
    @Log(title = "商品规格名", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallGoodsSpec mallGoodsSpec)
    {
        return toAjax(mallGoodsSpecService.updateMallGoodsSpec(mallGoodsSpec));
    }

    /**
     * 删除商品规格名
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpec:remove')")
    @Log(title = "商品规格名", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallGoodsSpecService.deleteMallGoodsSpecByIds(ids));
    }

    /**
     * 查询商品规格名列表
     */
    @GetMapping("/getSpecList")
    public AjaxResult getSpecList(MallGoodsSpec mallGoodsSpec)
    {
        List<MallGoodsSpec> list = mallGoodsSpecService.selectMallGoodsSpecSelectList(mallGoodsSpec);
        if (list.size()>0){
            MallGoodsSpecValue specValue = new MallGoodsSpecValue();
            for (MallGoodsSpec goodsSpec:list){
                specValue.setSpecId(goodsSpec.getId());
                List<MallGoodsSpecValue> list1 =mallGoodsSpecValueService.selectMallGoodsSpecValueList(specValue);
                goodsSpec.setSpec(list1);
            }
        }
        return AjaxResult.success(list);
    }
}
